#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # test about profiling
# 
# How to profile from a notebook with cProfile, memory_profiler

# In[1]:


from jyquickhelper import add_notebook_menu
add_notebook_menu()


# ### profiling with cProfile

# In[2]:


def big_list1(n):
    l = []
    for i in range(n):
        l.append(i)
    return l

def big_list2(n):
    return list(range(n))

def big_list(n):
    big_list1(n)
    big_list2(n)

get_ipython().run_line_magic('prun', '-q -T profile_example.txt -D profile_example.stat big_list(100000)')


# In[3]:


with open('profile_example.txt', 'r') as f: content = f.read()
print(content)


# In[4]:


import pstats
p = pstats.Stats('profile_example.stat')
p.strip_dirs().sort_stats('cumulative').print_stats()


# ### Memory profile

# In[5]:


from memory_profiler import memory_usage
mem_usage = memory_usage(-1, interval=.2, timeout=1)
mem_usage


# Thz functions to test must be part of file and cannot be implemented in the notebook. So we save the funtion in script and we import it just after.

# In[6]:


get_ipython().run_cell_magic('file', 'script_test.py', '\ndef big_list1(n):\n    l = []\n    for i in range(n):\n        l.append(i)\n    return l\n\ndef big_list2(n):\n    return list(range(n))\n\ndef big_list(n):\n    big_list1(n)\n    big_list2(n)\n')


# In[7]:


from script_test import big_list, big_list1, big_list2


# We run the momory profiling: 

# In[8]:


get_ipython().run_line_magic('load_ext', 'memory_profiler')


# In[9]:


prof = get_ipython().run_line_magic('mprun', '-r -f big_list1 -f big_list2 -T profile_example.mem -r big_list(100000)')


# In[10]:


with open('profile_example.mem', 'r') as f : content = f.read()
print(content)


# ### SnakeViz

# In[11]:


get_ipython().run_line_magic('load_ext', 'snakeviz')


# In[12]:


get_ipython().run_line_magic('system', 'snakeviz --help')


# See [How to visualize Python profile data with SnakeViz](http://codeyarns.com/2015/02/23/how-to-visualize-python-profile-data-with-snakeviz/).

# In[13]: